pub struct CachedSurfaceDescriptor {
pub prims: Vec<PrimitiveDescriptor>,
pub local_valid_rect: PictureRect,
pub last_updated_frame_id: FrameId,
pub dep_data: Vec<u8>,
pub vert_data: Vec<i32>,
}Expand description
Uniquely describes the content of this cached surface, in a way that can be (reasonably) efficiently hashed and compared.
Fields
prims: Vec<PrimitiveDescriptor>List of primitive instance unique identifiers. The uid is guaranteed to uniquely describe the content of the primitive template, while the other parameters describe the clip chain and instance params.
local_valid_rect: PictureRectPicture space rect that contains valid pixels region of this tile.
last_updated_frame_id: FrameIdThe last frame this tile had its dependencies updated (dependency updating is skipped if a tile is off-screen).
dep_data: Vec<u8>Packed per-prim dependency information
vert_data: Vec<i32>Per-tile quantized raster-space vert data. VertRanges stored in PrimitiveDescriptor and PrimitiveDependency::Clip index into this buffer.
Implementations